@@ -1,10 +1,11 @@
 package Ovirt::Cluster;
 
-use v5.16;
+use v5.10;
 use Carp;
 use Moo;
 
 with 'Ovirt';
+our $VERSION = '0.01';
 
 =head1 NAME
 
@@ -184,7 +185,7 @@ sub list {
         
         $clusterid = $self->trim($clusterid);
         
-        for my $element_id (keys $self->hash_output->{cluster}) {
+        for my $element_id ( 0 .. $#{ $self->hash_output->{cluster} } ) {
             next unless $self->hash_output->{cluster}[$element_id]->{id} eq $clusterid;
             
             $clusterid_element = $element_id;
@@ -212,7 +213,7 @@ sub list {
     }
     else {
         
-        for my $element_id (keys $self->hash_output->{cluster}) {
+        for my $element_id ( 0 .. $#{ $self->hash_output->{vm} } ) {
             
             # in case there's no any element left, the last element become the only attribute requested
             if (@attrs) {
